==> prompt_injection_bench-0.1.6-py3-none-any.whl: prompt_injection_bench/static/script.js <==
function openTab(evt, tabName) {
    // Declare all variables
    var i, tabcontent, tablinks;

    // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("control-panel-tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

     // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("results-tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

    // Get all elements with class="tablinks" and remove the class "active"
    tablinks = document.getElementsByClassName("tablinks");
    for (i = 0; i < tablinks.length; i++) {
        tablinks[i].className = tablinks[i].className.replace(" active", "");
    }

    // Show the current tab, and add an "active" class to the button that opened the tab
    document.getElementById(tabName).style.display = "block";
    evt.currentTarget.className += " active";
}

function getSelectedLLMs() {
    // Get all checkboxes with the same ID
    const checkboxes = document.querySelectorAll('input[type="checkbox"]:checked');

    // Create an array to store the selected fruit values
    const selectedLLMs = [];

    // Loop through all checkboxes
    checkboxes.forEach(function(checkbox) {
        if (checkbox.checked) {
            // Get the ID and value of the checked checkbox
            const checkboxValue = checkbox.value;
            const checkboxID = checkbox.id;
            // Add information to the selectedFruitsInfo array
            selectedLLMs.push({ id: checkboxID, value: checkboxValue });
        } else {
            // Handle unchecked checkboxes, e.g., add a message or treat them differently
            selectedLLMs.push(checkbox.value + " (unchecked)");
        }
    });

    // Return the selectedFruitsInfo array to another function
    return selectedLLMs;
}

// Function to establish a WebSocket connection
function startWebSocketConnection() {
    const websocket = new WebSocket("ws://127.0.0.1:9002/ws/start-analysis");
    const textarea = document.getElementById("results-textarea");

    websocket.onopen = (event) => {
        console.log("WebSocket connection established");
        websocket.send("start");
        // Create a new text node with the newText
        const newTextElement = document.createTextNode("\n\n");
        textarea.appendChild(newTextElement);
        textarea.scrollTop = textarea.scrollHeight;
    };

    websocket.onmessage = (event) => {
        if (event.data === "pong") {
            console.log("Received 'pong' from server"); // Handle the "pong" response
        } else {
            // Handle other incoming messages
            console.log("Received data message"); // Handle the "pong" response

            // const data = JSON.parse(event.data);

            // console.log(data);

            // Append the new results to the existing content with a line break
            const newText = `Results: ${event.data}\n`;

            // Create a new text node with the newText
            const newTextElement = document.createTextNode(newText);

            // Append the new text node to the textarea
            textarea.appendChild(newTextElement);

            // Automatically scroll to the bottom to show the latest content
            textarea.scrollTop = textarea.scrollHeight;
        }
    };

    websocket.onclose = (event) => {
        if (event.wasClean) {
            console.log(`Closed cleanly, code=${event.code}, reason=${event.reason}`);
        } else {
            console.log(`Connection died`);
        }
    };

    websocket.onerror = (error) => {
        console.error(`WebSocket Error: ${error}`);
    };
}

// Trigger Tab1 click on page load
window.onload = function() {
    document.getElementById("defaultOpen").click();
};

// Attach event listener to the "Start Analysis" button
document.getElementById("start-analysis-button").addEventListener("click", function() {
    openTab(event, "Results");
    startWebSocketConnection();
});

document.getElementById("enableOpenAI").addEventListener("click", function() {
    // Toggle OpenAI logic
});

document.getElementById("enableGemini").addEventListener("click", function() {
    // Toggle Gemini-Pro logic
});

==> prompt_injection_bench-0.1.12-py3-none-any.whl: prompt_injection_bench/static/script.js <==
function openTab(evt, tabName) {
    // Declare all variables
    var i, tabcontent, tablinks;

    // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("control-panel-tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

     // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("results-tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

    // Get all elements with class="tablinks" and remove the class "active"
    tablinks = document.getElementsByClassName("tablinks");
    for (i = 0; i < tablinks.length; i++) {
        tablinks[i].className = tablinks[i].className.replace(" active", "");
    }

    // Show the current tab, and add an "active" class to the button that opened the tab
    document.getElementById(tabName).style.display = "block";
    evt.currentTarget.className += " active";
}

function getSelectedLLMs() {
    // Get all checkboxes with the same ID
    const checkboxes = document.querySelectorAll('input[type="checkbox"]:checked');

    // Create an array to store the selected fruit values
    const selectedLLMs = [];

    // Loop through all checkboxes
    checkboxes.forEach(function(checkbox) {
        if (checkbox.checked) {
            // Get the ID and value of the checked checkbox
            const checkboxValue = checkbox.value;
            const checkboxID = checkbox.id;
            // Add information to the selectedFruitsInfo array
            selectedLLMs.push({ id: checkboxID, value: checkboxValue });
        } else {
            // Handle unchecked checkboxes, e.g., add a message or treat them differently
            selectedLLMs.push(checkbox.value + " (unchecked)");
        }
    });

    // Return the selectedFruitsInfo array to another function
    return selectedLLMs;
}

// Function to establish a WebSocket connection
function startWebSocketConnection() {
    const websocket = new WebSocket("ws://127.0.0.1:9002/ws/start-analysis");
    const textarea = document.getElementById("results-textarea");

    websocket.onopen = (event) => {
        console.log("WebSocket connection established");
        websocket.send("start");
        // Create a new text node with the newText
        const newTextElement = document.createTextNode("\n\n");
        textarea.appendChild(newTextElement);
        textarea.scrollTop = textarea.scrollHeight;
    };

    websocket.onmessage = (event) => {
        if (event.data === "pong") {
            console.log("Received 'pong' from server"); // Handle the "pong" response
        } else {
            // Handle other incoming messages
            console.log("Received data message"); // Handle the "pong" response
            let newStr = ""
            // Parse the JSON string to an object
            const data = JSON.parse(event.data);
            if (data.status && data.status === "complete") {
                // Take some action when status is "complete"
                newStr = "Analysis complete\n\n";
            } else {
                // Append the new results to the existing content with a line break
                const jsonStr = `${event.data}`;

                // Remove the outer curly braces
                newStr = jsonStr.slice(1, -1) + "\n"
            }
            // Create a new text node with the newText
            const newTextElement = document.createTextNode(newStr);
            // Append the new text node to the textarea
            textarea.appendChild(newTextElement);

            // Automatically scroll to the bottom to show the latest content
            textarea.scrollTop = textarea.scrollHeight;
        }
    };

    websocket.onclose = (event) => {
        if (event.wasClean) {
            console.log(`Closed cleanly, code=${event.code}, reason=${event.reason}`);
        } else {
            console.log(`Connection died`);
        }
    };

    websocket.onerror = (error) => {
        console.error(`WebSocket Error: ${error}`);
    };
}

// Trigger Tab1 click on page load
window.onload = function() {
    document.getElementById("defaultOpen").click();
};

// Attach event listener to the "Start Analysis" button
document.getElementById("start-analysis-button").addEventListener("click", function() {
    openTab(event, "Results");
    startWebSocketConnection();
});

document.getElementById("enableOpenAI").addEventListener("click", function() {
    // Toggle OpenAI logic
});

document.getElementById("enableGemini").addEventListener("click", function() {
    // Toggle Gemini-Pro logic
});
